<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr@ijekavianlatin" version="2.1">
<context>
    <name>TabManagerButton</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="50"/>
        <source>Tab Manager button</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Postavke menadžera jezičaka</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Odredite tip prikaza:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Bočna traka</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Prozor</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Napomena:&lt;/span&gt; „Prozor“ je preporučljivo za upravljanje mnogo prozora/jezičaka.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Koristi menadžera jezičaka kao zamjenu za glavnu traku jezičaka.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Menadžer jezičaka</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="110"/>
        <source>Local File System:</source>
        <translation>Lokalni fajl sistem:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="113"/>
        <source>QupZilla:</source>
        <translation>Kapzila:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="116"/>
        <source> [FTP]</source>
        <translation>[FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="301"/>
        <source>Group by</source>
        <translation>Grupiši po</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="302"/>
        <source>&amp;Window</source>
        <translation>&amp;prozoru</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="307"/>
        <source>&amp;Domain</source>
        <translation>&amp;domenu</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="312"/>
        <source>&amp;Host</source>
        <translation>do&amp;maćinu</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="320"/>
        <source>&amp;Show side by side</source>
        <translation>Prikaži &amp;jedan uz drugi</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="326"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Otkači označene jezičke</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="327"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>O&amp;bilježi označene jezičke</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="328"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;Zatvori označene jezičke</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="329"/>
        <source>&amp;Unload checked tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="581"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Odredite fasciklu za obilježivače:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="582"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Obilježi izabrane jezičke</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="700"/>
        <source>Window %1</source>
        <translation>Prozor %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="701"/>
        <source>Double click to switch</source>
        <translation>Dvoklik za prebacivanje</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="68"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="73"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="99"/>
        <source>Tab Manager</source>
        <translation>Menadžer jezičaka</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="100"/>
        <source>Show Tab Manager</source>
        <translation>Prikaži menadžera jezičaka</translation>
    </message>
</context>
</TS>